import { JupyterFrontEnd } from '@jupyterlab/application';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { IIterator } from '@lumino/algorithm';
import { Token } from '@lumino/coreutils';
import { ISignal } from '@lumino/signaling';
import { Widget } from '@lumino/widgets';
/**
 * The Jupyter Notebook application shell token.
 */
export declare const INotebookShell: Token<INotebookShell>;
/**
 * The Jupyter Notebook application shell interface.
 */
export interface INotebookShell extends NotebookShell {
}
/**
 * The application shell.
 */
export declare class NotebookShell extends Widget implements JupyterFrontEnd.IShell {
    constructor();
    /**
     * A signal emitted when the current widget changes.
     */
    get currentChanged(): ISignal<NotebookShell, void>;
    /**
     * The current widget in the shell's main area.
     */
    get currentWidget(): Widget | null;
    /**
     * Get the top area wrapper panel
     */
    get top(): Widget;
    /**
     * Get the menu area wrapper panel
     */
    get menu(): Widget;
    /**
     * Activate a widget in its area.
     */
    activateById(id: string): void;
    /**
     * Add a widget to the application shell.
     *
     * @param widget - The widget being added.
     *
     * @param area - Optional region in the shell into which the widget should
     * be added.
     *
     * @param options - Optional open options.
     *
     */
    add(widget: Widget, area?: Shell.Area, options?: DocumentRegistry.IOpenOptions): void;
    /**
     * Collapse the top area and the spacer to make the view more compact.
     */
    collapseTop(): void;
    /**
     * Expand the top area to show the header and the spacer.
     */
    expandTop(): void;
    /**
     * Return the list of widgets for the given area.
     *
     * @param area The area
     */
    widgets(area: Shell.Area): IIterator<Widget>;
    private _topWrapper;
    private _topHandler;
    private _menuWrapper;
    private _menuHandler;
    private _spacer;
    private _main;
    private _currentChanged;
}
/**
 * A namespace for Shell statics
 */
export declare namespace Shell {
    /**
     * The areas of the application shell where widgets can reside.
     */
    type Area = 'main' | 'top' | 'menu';
}
